==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/fr/information.php <==
<?php
return [
  '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => 'Module « Notifications push (Firebase) » et configuration de la clé API de Firebase nécessaires',
  '<strong>CronJob</strong> Status' => 'Statut des <strong>tâches planifiées</strong>',
  '<strong>Queue</strong> Status' => 'Statut de la <strong>file d\'attente</strong>',
  'About HumHub' => 'À propos de HumHub',
  'Assets' => 'Répertoire "/assets"',
  'Background Jobs' => 'Tâches de fond',
  'Base URL' => 'URL de base',
  'Checking HumHub software prerequisites.' => 'Vérification des prérequis logiciels de HumHub',
  'Configuration File' => 'Fichier de configuration',
  'Current limit is: {currentLimit}' => 'limite actuelle : {currentLimit}',
  'Custom Modules ({modules})' => 'Modules personnels ({modules})',
  'Database' => 'Base de données',
  'Database collation' => 'Classement (collation) de la base de données',
  'Database driver - {driver}' => 'Pilote de base de données - {driver}',
  'Database migration results:' => 'Résultats de la migration de la base de donnée :',
  'Delayed' => 'Retardé',
  'Deprecated Modules ({modules})' => 'Modules obsolètes ({modules})',
  'Detected URL: {currentBaseUrl}' => 'URL détectée : {currentBaseUrl}',
  'Different table collations in the tables: {tables}' => 'Collations différentes dans les tables : {tables}',
  'Disabled Functions' => 'Fonctions désactivées',
  'Displaying {count} entries per page.' => '{count} entrées par page.',
  'Done' => 'Terminé',
  'Driver' => 'Pilote',
  'Dynamic Config' => 'Fichier /protected/config/dynamic.php',
  'Error' => 'Erreur',
  'Flush entries' => 'Vider le journal',
  'HumHub' => 'HumHub',
  'HumHub Documentation' => 'Documentation de HumHub',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub est actuellement en mode débogage. Désactivez cette option quand le site est en production.',
  'ICU Data Version ({version})' => 'Version des données ICU ({version})',
  'ICU Data {icuMinVersion} or higher is required' => 'Les données ICU {icuMinVersion} ou ultérieures sont requises',
  'ICU Version ({version})' => 'Version d’ICU ({version})',
  'ICU {icuMinVersion} or higher is required' => 'ICU ({icuMinVersion}) ou ultérieure est requise',
  'Increase memory limit in {fileName}' => 'Augmentez la mémoire maximale dans {fileName}',
  'Info' => 'Info',
  'Install {phpExtension} Extension' => 'Installez l’extension {phpExtension}',
  'Install {phpExtension} Extension for APC Caching' => 'Installez l’extension {phpExtension} pour utiliser le cache APC',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Installez l’extension {phpExtension} pour gérer S/MIME avec les e-mails.',
  'Last run (daily):' => 'Dernière exécution (une fois par jour) :',
  'Last run (hourly):' => 'Dernière exécution (toutes les heures) :',
  'Licences' => 'Licences',
  'Logging' => 'Journal',
  'Make sure that the `proc_open` function is not disabled.' => 'Vérifiez que la fonction `proc_open` n’est pas désactivée.',
  'Make {filePath} writable for the Webserver/PHP!' => 'Rendez {filePath} accessible en écriture pour le serveur web / PHP !',
  'Marketplace API Connection' => 'Connexion API Marketplace',
  'Memory Limit ({memoryLimit})' => 'Limite maximale de mémoire ({memoryLimit})',
  'Minimum Version {minVersion}' => 'Version minimale {minVersion}',
  'Mobile App - Push Service' => 'Appli mobile – service push',
  'Module Directory' => 'Répertoire "/protected/modules"',
  'Multibyte String Functions' => 'Fonctions de chaînes de caractères multi-octets',
  'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => 'Doivent être mis à jour manuellement. Avant leur mise à jour, vérifiez leur compatibilité avec les versions plus récentes de HumHub.',
  'Never' => 'Jamais',
  'New migrations should be applied: {migrations}' => 'De nouvelles migrations devraient être effectuées : {migrations}',
  'No pending migrations' => 'Aucune migration en attente',
  'Optional' => 'Optionnel',
  'Other' => 'Autre',
  'Outstanding database migrations:' => 'Migrations de la base de données en attente :',
  'Permissions' => 'Permissions',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Veuillez consulter la documentation pour paramétrer les tâches planifiées (cronjobs) et travailleurs en liste.',
  'Prerequisites' => 'Prérequis',
  'Pretty URLs' => 'Pretty URL',
  'Profile Image' => 'Répertoire des images de profils',
  'Queue successfully cleared.' => 'File d’attente vidée avec succès.',
  'Re-Run tests' => 'Relancer les vérifications',
  'Rebuild search index' => 'Reconstruire l’index de recherche',
  'Recommended collation is {collation}' => 'Le classement (collation) recommandé est {collation}',
  'Recommended collation is {collation} for the tables: {tables}' => 'Le classement (collation) recommandé est {collation} pour les tables : {tables}',
  'Recommended engine is {engine} for the tables: {tables}' => 'Le moteur recommandé est {engine} pour les tables : {tables}',
  'Refresh' => 'Rafraîchir',
  'Reserved' => 'Réservé',
  'Runtime' => 'Répertoire "/protected/runtime"',
  'Search index rebuild in progress.' => 'Reconstruction de l\'index de recherche en cours.',
  'Search term...' => 'Rechercher le terme…',
  'See installation manual for more details.' => 'Voir le manuel d\'installation pour plus de détails.',
  'Select category..' => 'Sélectionner la catégorie…',
  'Select day' => 'Sélectionner le jour',
  'Select level...' => 'Sélectionner le(s) niveau(x)…',
  'Settings' => 'Réglages',
  'Supported drivers: {drivers}' => 'Pilotes gérés : {drivers}',
  'Table collations' => 'Classements (collations) des tables',
  'Table engines' => 'Moteurs des tables',
  'The configuration file contains legacy settings. Invalid options: {options}' => 'Le fichier de configuration contient des réglages de versions antérieures. Options non valides : {options}',
  'The current main HumHub database name is ' => 'Le nom actuel de la base de donnée principale de Humhub est',
  'The module(s) are no longer maintained and should be uninstalled.' => 'Ces modules ne sont plus entretenus et devraient être désinstallés.',
  'There is a new update available! (Latest version: %version%)' => 'Une nouvelle version est disponible : %version%',
  'This HumHub installation is up to date!' => 'Cette installation de HumHub est à jour.',
  'Total {count} entries found.' => '{count} entrées trouvées au total.',
  'Trace' => 'Trace',
  'Update Database' => 'Mettre à jour la base de données',
  'Uploads' => 'Répertoire "/uploads"',
  'Varying table engines are not supported.' => 'Des moteurs de tables distincts ne sont pas gérés.',
  'Version' => 'Version',
  'Waiting' => 'En attente',
  'Warning' => 'Attention',
  'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => 'Version PHP de l’application web : `{webPhpVersion}`, version PHP Cron : `{cronPhpVersion}`',
  'Web Application and Cron uses the same PHP version' => 'L’application web et Cron utilisent la même version PHP',
  'Web Application and Cron uses the same user' => 'L’application web et Cron utilisent le même compte',
  'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => 'Compte de l’application web : `{webUser}`, compte de Cron : `{cronUser}`',
  'Your database is <b>up-to-date</b>.' => 'Votre base de données est <b>à jour</b>.',
  '{imageExtension} Support' => 'Gestion de {imageExtension}',
  '{phpExtension} Extension' => 'Extension {phpExtension}',
  '{phpExtension} Support' => 'Gestion de {phpExtension}',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/fr/information.php <==
<?php
return [
  '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => 'Module « Notifications push (Firebase) » et configuration de la clé API de Firebase nécessaires',
  '<strong>CronJob</strong> Status' => 'Statut des <strong>tâches planifiées</strong>',
  '<strong>Queue</strong> Status' => 'Statut de la <strong>file d\'attente</strong>',
  'About HumHub' => 'À propos de HumHub',
  'Assets' => 'Répertoire "/assets"',
  'Background Jobs' => 'Tâches de fond',
  'Base URL' => 'URL de base',
  'Checking HumHub software prerequisites.' => 'Vérification des prérequis logiciels de HumHub',
  'Configuration File' => 'Fichier de configuration',
  'Current limit is: {currentLimit}' => 'limite actuelle : {currentLimit}',
  'Custom Modules ({modules})' => 'Modules personnels ({modules})',
  'Database' => 'Base de données',
  'Database collation' => 'Classement (collation) de la base de données',
  'Database driver - {driver}' => 'Pilote de base de données - {driver}',
  'Database migration results:' => 'Résultats de la migration de la base de donnée :',
  'Delayed' => 'Retardé',
  'Deprecated Modules ({modules})' => 'Modules obsolètes ({modules})',
  'Detected URL: {currentBaseUrl}' => 'URL détectée : {currentBaseUrl}',
  'Different table collations in the tables: {tables}' => 'Collations différentes dans les tables : {tables}',
  'Disabled Functions' => 'Fonctions désactivées',
  'Displaying {count} entries per page.' => '{count} entrées par page.',
  'Done' => 'Terminé',
  'Driver' => 'Pilote',
  'Enable <a href="{url}">Link Redirection Service</a>' => 'Activer le <a href="{url}">Service de Redirection de Lien</a>',
  'Error' => 'Erreur',
  'Flush entries' => 'Vider le journal',
  'HumHub' => 'HumHub',
  'HumHub Documentation' => 'Documentation de HumHub',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub est actuellement en mode débogage. Désactivez cette option quand le site est en production.',
  'ICU Data Version ({version})' => 'Version des données ICU ({version})',
  'ICU Data {icuMinVersion} or higher is required' => 'Les données ICU {icuMinVersion} ou ultérieures sont requises',
  'ICU Version ({version})' => 'Version d’ICU ({version})',
  'ICU {icuMinVersion} or higher is required' => 'ICU ({icuMinVersion}) ou ultérieure est requise',
  'Increase memory limit in {fileName}' => 'Augmentez la mémoire maximale dans {fileName}',
  'Info' => 'Info',
  'Install {phpExtension} Extension' => 'Installez l’extension {phpExtension}',
  'Install {phpExtension} Extension for APC Caching' => 'Installez l’extension {phpExtension} pour utiliser le cache APC',
  'Install {phpExtension} Extension for Mercure push live driver' => 'Installez l\'extension {phpExtension} pour le driver push temps réel "Mercure".',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Installez l’extension {phpExtension} pour gérer S/MIME avec les e-mails.',
  'Last run (daily):' => 'Dernière exécution (une fois par jour) :',
  'Last run (hourly):' => 'Dernière exécution (toutes les heures) :',
  'Licences' => 'Licences',
  'Logging' => 'Journal',
  'Make sure that the `proc_open` function is not disabled.' => 'Vérifiez que la fonction `proc_open` n’est pas désactivée.',
  'Make {filePath} writable for the Webserver/PHP!' => 'Rendez {filePath} accessible en écriture pour le serveur web / PHP !',
  'Marketplace API Connection' => 'Connexion API Marketplace',
  'Memory Limit ({memoryLimit})' => 'Limite maximale de mémoire ({memoryLimit})',
  'Minimum Version {minVersion}' => 'Version minimale {minVersion}',
  'Mobile App - Push Service' => 'Appli mobile – service push',
  'Module Directory' => 'Répertoire "/protected/modules"',
  'Multibyte String Functions' => 'Fonctions de chaînes de caractères multi-octets',
  'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => 'Doivent être mis à jour manuellement. Avant leur mise à jour, vérifiez leur compatibilité avec les versions plus récentes de HumHub.',
  'Never' => 'Jamais',
  'New migrations should be applied: {migrations}' => 'De nouvelles migrations devraient être effectuées : {migrations}',
  'No pending migrations' => 'Aucune migration en attente',
  'Optional' => 'Optionnel',
  'Other' => 'Autre',
  'Outstanding database migrations:' => 'Migrations de la base de données en attente :',
  'Permissions' => 'Permissions',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Veuillez consulter la documentation pour paramétrer les tâches planifiées (cronjobs) et travailleurs en liste.',
  'Prerequisites' => 'Prérequis',
  'Pretty URLs' => 'Pretty URL',
  'Profile Image' => 'Répertoire des images de profils',
  'Queue successfully cleared.' => 'File d’attente vidée avec succès.',
  'Re-Run tests' => 'Relancer les vérifications',
  'Rebuild search index' => 'Reconstruire l’index de recherche',
  'Recommended collation is {collation}' => 'Le classement (collation) recommandé est {collation}',
  'Recommended collation is {collation} for the tables: {tables}' => 'Le classement (collation) recommandé est {collation} pour les tables : {tables}',
  'Recommended engine is {engine} for the tables: {tables}' => 'Le moteur recommandé est {engine} pour les tables : {tables}',
  'Refresh' => 'Rafraîchir',
  'Reserved' => 'Réservé',
  'Runtime' => 'Répertoire "/protected/runtime"',
  'Search index rebuild in progress.' => 'Reconstruction de l\'index de recherche en cours.',
  'Search term...' => 'Rechercher le terme…',
  'See installation manual for more details.' => 'Voir le manuel d\'installation pour plus de détails.',
  'Select category..' => 'Sélectionner la catégorie…',
  'Select day' => 'Sélectionner le jour',
  'Select level...' => 'Sélectionner le(s) niveau(x)…',
  'Settings' => 'Réglages',
  'Supported drivers: {drivers}' => 'Pilotes gérés : {drivers}',
  'Table collations' => 'Classements (collations) des tables',
  'Table engines' => 'Moteurs des tables',
  'The configuration file contains legacy settings. Invalid options: {options}' => 'Le fichier de configuration contient des réglages de versions antérieures. Options non valides : {options}',
  'The current main HumHub database name is ' => 'Le nom actuel de la base de donnée principale de Humhub est',
  'The module(s) are no longer maintained and should be uninstalled.' => 'Ces modules ne sont plus entretenus et devraient être désinstallés.',
  'There is a new update available! (Latest version: %version%)' => 'Une nouvelle version est disponible : %version%',
  'This HumHub installation is up to date!' => 'Cette installation de HumHub est à jour.',
  'Total {count} entries found.' => '{count} entrées trouvées au total.',
  'Trace' => 'Trace',
  'Update Database' => 'Mettre à jour la base de données',
  'Uploads' => 'Répertoire "/uploads"',
  'Uploads - File' => 'Téléchargements - Fichier',
  'Varying table engines are not supported.' => 'Des moteurs de tables distincts ne sont pas gérés.',
  'Version' => 'Version',
  'Waiting' => 'En attente',
  'Warning' => 'Attention',
  'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => 'Version PHP de l’application web : `{webPhpVersion}`, version PHP Cron : `{cronPhpVersion}`',
  'Web Application and Cron uses the same PHP version' => 'L’application web et Cron utilisent la même version PHP',
  'Web Application and Cron uses the same user' => 'L’application web et Cron utilisent le même compte',
  'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => 'Compte de l’application web : `{webUser}`, compte de Cron : `{cronUser}`',
  'Your database is <b>up-to-date</b>.' => 'Votre base de données est <b>à jour</b>.',
  '{imageExtension} Support' => 'Gestion de {imageExtension}',
  '{phpExtension} Extension' => 'Extension {phpExtension}',
  '{phpExtension} Support' => 'Gestion de {phpExtension}',
];
